#include <iostream>
#include <fstream>
#include <string>
#include <cassert>

//
// NOTE: You are allowed to modify the provided code as much as needed to
// complete this homework.
//

// --------------------------------------------------------------------------
// Read one ASCII Art puzzle board from the input file.
// Return true if the board was successfully read.

bool ReadBoard(std::ifstream &istr, std::vector<std::string> &input) {
  input.clear();
  std::string s;
  int width = 0;
   
  // search through the file to find a line that is the top of a board
  while (std::getline(istr,s)) {
    if (s.size() > 2 && s[0] == '+') break;
  }
  // if we didn't find a board, return false
  if (s.size() <= 2 || s[0] != '+') return false;

  // make sure the top line is formatted correctly
  width = s.size()-2;
  assert (s[0] == '+');
  assert (s[s.size()-1] == '+');  
  for (unsigned int i = 1; i < s.size()-2; i++) { assert (s[i] == '-'); }
  
  // read each row of the board
  while (true) {
    std::getline(istr,s);
    assert (int(s.size()) == width+2);
    if (s[0] == '+') { break; }
    assert (s[s.size()-1] == '|');
    assert (s[0] == '|');
    s.pop_back();
    s.erase(s.begin());
    input.push_back(s);
  }

  // read the bottom line
  assert (s[s.size()-1] == '+');  
  for (unsigned int i = 1; i < s.size()-2; i++) { assert (s[i] == '-'); }

  // the board was successfully read!
  return true;
}


// --------------------------------------------------------------------------
int main(int argc, char* argv[]) {

  // the command line has 1 or more arguments
  assert (argc >= 2);

  // the first argument is the filename of the input board
  std::string input_file = argv[1];

  // default values for the optional command line arguments
  bool find_one_solution = true;
  bool find_all_solutions = false;
  bool print_islands = false;
  bool print_check_solution = false;
  bool print_solution_count = false;

  for (int i = 2; i < argc; i++) {
    std::string a = std::string(argv[i]);
    if (a == "--no_solver") {
      find_one_solution = false;
      find_all_solutions = false;
    } else if (a == "--find_all_solutions") {
      find_one_solution = false;
      find_all_solutions = true;
    } else if (a == "--print_islands") {
      print_islands = true;
    } else if (a == "--print_check_solution")  {
      print_check_solution = true;
    } else if (a == "--print_solution_count")  {
      print_solution_count = true; }
    else {
      std::cerr << "ERROR: Invalid command line argument '" << a << "'" << std::endl;
      exit(1);
    }
  }

  // the input file may contain multiple boards to analyze & solve
  std::ifstream istr(input_file);
  assert (istr.good());
  std::vector<std::string> input;

  while (ReadBoard(istr,input)) {

    // how many solutions did your program find?
    int count = 0;
    
    if (find_one_solution) {

      // FILL IN
      
    } else if (find_all_solutions) {

      // FILL IN
      
    } else {

      // no solver!  Just analyze and print

      // FILL IN
      
    }
    
    if (print_solution_count) {
      if (count == 0) {
        std::cout << "Found No Solutions" << std::endl;
      } else if (count == 1) {
        std::cout << "Found 1 Solution" << std::endl;
      } else {
        std::cout << "Found " << count << " Solutions" << std::endl;
      }
    }
  }
}

// --------------------------------------------------------------------------
